..
      Copyright 2015 IBM
      All Rights Reserved.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

Networking-PowerVM Policies
===========================

In the Policies Guide, you will find documented policies for developing with
Networking-PowerVM. This includes the processes we use for blueprints and specs,
bugs, contributor onboarding, and other procedural items.

Policies
--------
.. toctree::
    :maxdepth: 3

    bugs
    contributing
    code-reviews

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

